
Authentication enforced by the web-sever
-------

**Description:**

Authentication should be enforced by the web-server. Whenever these configurations are 
not enabled on the server an attacker could gain access to authorised 
pages on your application.


**Solution:**

Always make sure your web-server is correctly configured to enforce authentication, 
such as a session management implementation.


	
